@@ -600,7 +600,7 @@ _l3cd_config_add(NML3IPv4LL *self)
         nm_assert_not_reached();
 
     self->l3cfg_commit_handle = nm_l3cfg_commit_type_register(self->l3cfg,
-                                                              NM_L3_CFG_COMMIT_TYPE_ASSUME,
+                                                              NM_L3_CFG_COMMIT_TYPE_UPDATE,
                                                               self->l3cfg_commit_handle,
                                                               "ipv4ll");
     nm_l3cfg_commit_on_idle_schedule(self->l3cfg, NM_L3_CFG_COMMIT_TYPE_AUTO);
