@@ -2119,10 +2119,27 @@ test_hostname_is_valid(void)
     g_assert(!nm_hostname_is_valid(".foobar", FALSE));
     g_assert(!nm_hostname_is_valid("foo..bar", FALSE));
     g_assert(!nm_hostname_is_valid("foo.bar..", FALSE));
-    g_assert(
-        !nm_hostname_is_valid("xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
-                              "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
-                              FALSE));
+
+    G_STATIC_ASSERT_EXPR(NM_HOST_NAME_MAX <= HOST_NAME_MAX);
+
+#define _assert_hostname_length(n, valid)         \
+    G_STMT_START                                  \
+    {                                             \
+        const gsize   _n = (n);                   \
+        gs_free char *_h = g_strnfill(_n, 'x');   \
+        gboolean      _valid;                     \
+                                                  \
+        _valid = nm_hostname_is_valid(_h, FALSE); \
+        g_assert_cmpint(_valid, ==, (valid));     \
+    }                                             \
+    G_STMT_END
+
+    _assert_hostname_length(NM_HOST_NAME_MAX - 10, TRUE);
+    _assert_hostname_length(NM_HOST_NAME_MAX - 1, TRUE);
+    _assert_hostname_length(NM_HOST_NAME_MAX, TRUE);
+    _assert_hostname_length(NM_HOST_NAME_MAX + 1, FALSE);
+    _assert_hostname_length(NM_HOST_NAME_MAX + 10, FALSE);
+
     g_assert(!nm_hostname_is_valid(
         "au-xph5-rvgrdsb5hcxc-47et3a5vvkrc-server-wyoz4elpdpe3.openstack.local",
         FALSE));
@@ -2142,6 +2159,9 @@ test_hostname_is_valid(void)
     g_assert(!nm_hostname_is_valid(".foobar", TRUE));
     g_assert(!nm_hostname_is_valid("foo..bar", TRUE));
     g_assert(!nm_hostname_is_valid("foo.bar..", TRUE));
+    g_assert(
+        nm_hostname_is_valid("xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
+                             TRUE));
     g_assert(
         !nm_hostname_is_valid("xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
                               "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
